@@ -1,5 +1,23 @@
-#ifndef _SIGC_ADAPTORS_RETYPE_H_
-#define _SIGC_ADAPTORS_RETYPE_H_
+/*
+ * Copyright 2003 - 2016, The libsigc++ Development Team
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2.1 of the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ *  Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ */
+
+#ifndef SIGC_ADAPTORS_RETYPE_H
+#define SIGC_ADAPTORS_RETYPE_H
 
 #include <sigc++/adaptors/adapts.h>
 #include <sigc++/functors/ptr_fun.h>
@@ -58,21 +76,21 @@ namespace sigc
  *
  * @ingroup retype
  */
-template <class T_functor, class... T_type>
+template <typename T_functor, typename... T_type>
 struct retype_functor : public adapts<T_functor>
 {
-  template <class... T_arg>
-  decltype(auto) operator()(T_arg... _A_a)
+  template <typename... T_arg>
+  decltype(auto) operator()(T_arg... a)
   {
     return this->functor_.template operator()<type_trait_take_t<T_type>...>(
-      static_cast<T_type>(_A_a)...);
+      static_cast<T_type>(a)...);
   }
 
   /** Constructs a retype_functor object that performs C-style casts on the parameters passed on to
    * the functor.
-   * @param _A_functor Functor to invoke from operator()().
+   * @param functor Functor to invoke from operator()().
    */
-  explicit retype_functor(type_trait_take_t<T_functor> _A_functor) : adapts<T_functor>(_A_functor)
+  explicit retype_functor(type_trait_take_t<T_functor> functor) : adapts<T_functor>(functor)
   {
   }
 };
@@ -85,14 +103,14 @@ struct retype_functor : public adapts<T_functor>
  *
  * @ingroup retype
  */
-template <class T_functor, class... T_type>
+template <typename T_functor, typename... T_type>
 struct visitor<retype_functor<T_functor, T_type...>>
 {
   template <typename T_action>
   static void do_visit_each(
-    const T_action& _A_action, const retype_functor<T_functor, T_type...>& _A_target)
+    const T_action& action, const retype_functor<T_functor, T_type...>& target)
   {
-    sigc::visit_each(_A_action, _A_target.functor_);
+    sigc::visit_each(action, target.functor_);
   }
 };
 #endif // DOXYGEN_SHOULD_SKIP_THIS
@@ -101,34 +119,34 @@ struct visitor<retype_functor<T_functor, T_type...>>
 /** Creates an adaptor of type sigc::retype_functor which performs C-style casts on the parameters
  * passed on to the functor.
  *
- * @param _A_functor Functor that should be wrapped.
- * @return Adaptor that executes @e _A_functor performing C-style casts on the paramters passed on.
+ * @param functor Functor that should be wrapped.
+ * @return Adaptor that executes @e functor performing C-style casts on the paramters passed on.
  *
  * @ingroup retype
  */
-template <template <class T_func, class... T_arg> class T_functor, class T_func, class... T_arg>
+template <template <typename T_func, typename... T_arg> class T_functor, typename T_func, typename... T_arg>
 inline decltype(auto)
-retype(const T_functor<T_func, T_arg...>& _A_functor)
+retype(const T_functor<T_func, T_arg...>& functor)
 {
-  return retype_functor<T_functor<T_func, T_arg...>, T_arg...>(_A_functor);
+  return retype_functor<T_functor<T_func, T_arg...>, T_arg...>(functor);
 }
 
 // This one takes, for instance, a pointer_functor or slot:
 /** Creates an adaptor of type sigc::retype_functor which performs C-style casts on the parameters
  * passed on to the functor.
  *
- * @param _A_functor Functor that should be wrapped.
- * @return Adaptor that executes @e _A_functor performing C-style casts on the paramters passed on.
+ * @param functor Functor that should be wrapped.
+ * @return Adaptor that executes @e functor performing C-style casts on the paramters passed on.
  *
  * @ingroup retype
  */
-template <template <class T_return, class... T_arg> class T_functor, class T_return, class... T_arg>
+template <template <typename T_return, typename... T_arg> class T_functor, typename T_return, typename... T_arg>
 inline decltype(auto)
-retype(const T_functor<T_return(T_arg...)>& _A_functor)
+retype(const T_functor<T_return(T_arg...)>& functor)
 {
-  return retype_functor<T_functor<T_return(T_arg...)>, T_arg...>(_A_functor);
+  return retype_functor<T_functor<T_return(T_arg...)>, T_arg...>(functor);
 }
 
 } /* namespace sigc */
 
-#endif /* _SIGC_ADAPTORS_RETYPE_H_ */
+#endif /* SIGC_ADAPTORS_RETYPE_H */
