@@ -20,25 +20,19 @@
 #define SIGC_CONNECTION_HPP
 #include <sigc++config.h>
 #include <sigc++/functors/slot_base.h>
+#include <sigc++/weak_raw_ptr.h>
 
 namespace sigc
 {
 
-/** Convinience class for safe disconnection.
- * Iterators must not be used beyond the lifetime of the list
- * they work on. A connection object can be created from a
- * slot list iterator and may safely be used to disconnect
- * the referred slot at any time (disconnect()). If the slot
- * has already been destroyed, disconnect() does nothing. empty() or
+/** This may be used to disconnect the referred slot at any time (disconnect()).
+ * If the slot has already been destroyed, disconnect() does nothing. empty() or
  * operator bool() can be used to test whether the connection is
  * still active. The connection can be blocked (block(), unblock()).
  *
- * This is possible because the connection object gets notified
- * when the referred slot dies (notify()).
- *
  * @ingroup signal
  */
-struct SIGC_API connection : public notifiable
+struct SIGC_API connection
 {
   /** Constructs an empty connection object. */
   connection() noexcept;
@@ -96,17 +90,12 @@ struct SIGC_API connection : public notifiable
   explicit operator bool() const noexcept;
 
 private:
-  void set_slot(slot_base* sl);
-
-  /** Callback that is executed when the referred slot is destroyed.
-   * @param data The connection object notified (@p this).
-   */
-  static void notify_slot_invalidated(notifiable* data);
+  void set_slot(const sigc::internal::weak_raw_ptr<slot_base>& sl);
 
   /* Referred slot. Set to zero from notify().
    * A value of zero indicates an "empty" connection.
    */
-  slot_base* slot_;
+  sigc::internal::weak_raw_ptr<slot_base> slot_;
 };
 
 } /* namespace sigc */
