@@ -1,5 +1,4 @@
-// -*- c++ -*-
-/* Copyright 2002, The libsigc++ Development Team
+/* Copyright 2002 - 2016, The libsigc++ Development Team
  *  Assigned to public domain.  Use as you wish without restriction.
  */
 
@@ -28,7 +27,7 @@ struct foo
 
 struct bar : public sigc::trackable
 {
-  bar(int i = 0) : i_(i) {}
+  explicit bar(int i = 0) : i_(i) {}
   operator int() { return i_; }
   int i_;
 };
